alias

package
v0.1.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 11, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package alias provides unprefixed names for the json command's public API.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func JSON

func JSON(opts ...any) gloo.Command[[]byte, []byte]

JSON re-exports the command.JSON constructor.

func Query

func Query(q command.QueryScript) gloo.Command[[]byte, []byte]

Query re-exports the command.Query constructor — run a cirql pipeline query.

Types

type QueryScript

type QueryScript = command.QueryScript

QueryScript is the source text of a cirql pipeline query.

Jump to