Documentation
¶
Overview ¶
Package alias provides unprefixed names for the json command's public API.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type QueryScript ¶
type QueryScript = command.QueryScript
QueryScript is the source text of a cirql pipeline query.
Click to show internal directories.
Click to hide internal directories.