fromtoml

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 3, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FromToml

func FromToml(opts ...any) gloo.Command[[]byte, []byte]

FromToml converts a TOML document on the input into a single compact JSON object, letting TOML feed the rest of the json pipeline. The whole input is one document, so it is buffered and emitted as one value.

Types

type Error

type Error string

Error is the sentinel error type for the fromtoml package.

func (Error) Error

func (e Error) Error() string

Jump to